const assert = require('assert')
const FixedArray = require('.')

describe('FixedArray', () => {
  it('inherits from Array', () => {
    assert(new FixedArray() instanceof Array)
  })

  it('don\'t have pop() and shift() methods', () => {
    const array = new FixedArray()
    assert.strictEqual(array.pop, undefined)
    assert.strictEqual(array.shift, undefined)
  })

  describe('push()', () => {
    it('doesn\'t change length of array', () => {
      const array = new FixedArray(2)
      assert.strictEqual(array.length, 2)
      array.push('TEST')
      assert.strictEqual(array.length, 2)
    })

    it('removes element from other end of array', () => {
      const array = FixedArray.from([ 1, 2 ])
      assert.deepEqual(array, [ 1, 2 ])
      array.push(3)
      assert.deepEqual(array, [ 2, 3 ])
    })
  })

  describe('unshift()', () => {
    it('doesn\'t change length of array', () => {
      const array = new FixedArray(2)
      assert.strictEqual(array.length, 2)
      array.unshift('TEST')
      assert.strictEqual(array.length, 2)
    })

    it('removes element from other end of array', () => {
      const array = FixedArray.from([ 1, 2 ])
      assert.deepEqual(array, [ 1, 2 ])
      array.unshift(0)
      assert.deepEqual(array, [ 0, 1 ])
    })
  })
})
